@@ -1,9 +1,10 @@
 """Handle running, parsing and manipulating metrics available through Picard.
 """
-import os
+import contextlib
 import glob
 import json
-import contextlib
+import os
+import subprocess
 
 from bcbio.utils import tmpfile, file_exists
 from bcbio.distributed.transaction import file_transaction
@@ -284,7 +285,7 @@ class PicardMetrics(object):
         self._parser = PicardMetricsParser()
 
     def report(self, align_bam, ref_file, is_paired, bait_file, target_file,
-               variant_region_file):
+               variant_region_file, config):
         """Produce report metrics using Picard with sorted aligned BAM file.
         """
         dup_metrics = self._get_current_dup_metrics(align_bam)
@@ -300,7 +301,9 @@ class PicardMetrics(object):
             assert os.path.exists(target_file), (target_file, "does not exist!")
             hybrid_metrics = self._hybrid_select_metrics(align_bam,
                                                          bait_file, target_file)
-        elif variant_region_file:
+        elif (variant_region_file and 
+              config["algorithm"].get("coverage_interval", "").lower() in ["exome"]):
+            assert os.path.exists(variant_region_file), (variant_region_file, "does not exist")
             hybrid_metrics = self._hybrid_select_metrics(
                 align_bam, variant_region_file, variant_region_file)
 
@@ -360,7 +363,13 @@ class PicardMetrics(object):
                                 ("TARGET_INTERVALS", ready_target),
                                 ("INPUT", dup_bam),
                                 ("OUTPUT", tx_metrics)]
-                        self._picard.run("CalculateHsMetrics", opts)
+                        try:
+                            self._picard.run("CalculateHsMetrics", opts)
+                        # HsMetrics fails regularly with memory errors
+                        # so we catch and skip instead of aborting the
+                        # full process
+                        except subprocess.CalledProcessError:
+                            return None
         return metrics
 
     def _variant_eval_metrics(self, dup_bam):
@@ -439,7 +448,7 @@ def bed_to_interval(orig_bed, bam_file):
         bam_handle = pysam.Samfile(bam_file, "rb")
         with contextlib.closing(bam_handle):
             header = bam_handle.text
-        with tmpfile(dir=os.getcwd(), prefix="picardbed") as tmp_bed:
+        with tmpfile(dir=os.path.dirname(orig_bed), prefix="picardbed") as tmp_bed:
             with open(tmp_bed, "w") as out_handle:
                 out_handle.write(header)
                 with open(orig_bed) as in_handle:
@@ -454,15 +463,14 @@ def bed_to_interval(orig_bed, bam_file):
 
 class RNASeqPicardMetrics(PicardMetrics):
 
-    def report(self, align_bam, ref_file, gtf_file, is_paired=False,
-               rrna_file="null"):
+    def report(self, align_bam, ref_file, gtf_file, is_paired=False, rrna_file="null"):
         """Produce report metrics for a RNASeq experiment using Picard
         with a sorted aligned BAM file.
 
         """
 
         # collect duplication metrics
-        dup_bam, dup_metrics = self._get_current_dup_metrics(align_bam)
+        dup_metrics = self._get_current_dup_metrics(align_bam)
         align_metrics = self._collect_align_metrics(align_bam, ref_file)
         insert_graph, insert_metrics = (None, None)
         if is_paired:
