@@ -3,7 +3,6 @@
 import contextlib
 import gzip
 import os
-import subprocess
 
 from Bio.SeqIO.QualityIO import FastqGeneralIterator
 
@@ -34,7 +33,7 @@ def align_bam(in_bam, ref_file, names, align_dir, config):
     max_mem = resources.get("memory", "768M")
     rg_info = novoalign.get_rg_info(names)
     if not utils.file_exists(out_file):
-        _check_samtools_version()
+        novoalign.check_samtools_version()
         with utils.curdir_tmpdir() as work_dir:
             with file_transaction(out_file) as tx_out_file:
                 tx_out_prefix = os.path.splitext(tx_out_file)[0]
@@ -51,21 +50,24 @@ def align_bam(in_bam, ref_file, names, align_dir, config):
 
 def can_pipe(fastq_file):
     """bwa-mem handle longer (> 75bp) reads with improved piping.
+    Default to no piping if more than half the first 500 reads are small.
     """
     min_size = 75
+    thresh = 0.5
+    tocheck = 500
+    shorter = 0
     if fastq_file.endswith(".gz"):
         handle = gzip.open(fastq_file, "rb")
     else:
         handle = open(fastq_file)
-    supports_piping = True
     with contextlib.closing(handle) as in_handle:
         fqit = FastqGeneralIterator(in_handle)
-        for i, (_, seq, qual) in enumerate(fqit):
+        for i, (_, seq, _) in enumerate(fqit):
             if len(seq) < min_size:
-                supports_piping = False
-            if i > 100:
+                shorter += 1
+            if i > tocheck:
                 break
-    return supports_piping
+    return (float(shorter) / float(tocheck)) <= thresh
 
 def align_pipe(fastq_file, pair_file, ref_file, names, align_dir, config):
     """Perform piped alignment of fastq input files, generating sorted output BAM.
@@ -79,7 +81,7 @@ def align_pipe(fastq_file, pair_file, ref_file, names, align_dir, config):
     max_mem = resources.get("memory", "768M")
     rg_info = novoalign.get_rg_info(names)
     if not utils.file_exists(out_file):
-        _check_samtools_version()
+        novoalign.check_samtools_version()
         with utils.curdir_tmpdir() as work_dir:
             with file_transaction(out_file) as tx_out_file:
                 tx_out_prefix = os.path.splitext(tx_out_file)[0]
@@ -92,19 +94,8 @@ def align_pipe(fastq_file, pair_file, ref_file, names, align_dir, config):
                        [do.file_nonempty(tx_out_file)])
     return out_file
 
-def _check_samtools_version():
-    """Ensure samtools has parallel processing required for piped analysis.
-    """
-    p = subprocess.Popen(["samtools", "sort"], stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-    output, _ = p.communicate()
-    p.stdout.close()
-    if output.find("-@") == -1:
-        raise OSError("Installed version of samtools sort does not have support for multithreading (-@ option) "
-                      "required to support bwa piped alignment. Please upgrade to the latest version "
-                      "from http://samtools.sourceforge.net/")
-
 def align(fastq_file, pair_file, ref_file, out_base, align_dir, config,
-          rg_name=None):
+          names=None):
     """Perform a BWA alignment, generating a SAM file.
     """
     sai1_file = os.path.join(align_dir, "%s_1.sai" % out_base)
