@@ -17,6 +17,8 @@ from bcbio.ngsalign import bowtie, bowtie2
 from bcbio.utils import safe_makedir, file_exists, get_in, flatten
 from bcbio.distributed.transaction import file_transaction
 from bcbio.log import logger
+from bcbio.provenance import do
+from bcbio.convert import bam2sam, bamindex
 from bcbio import broad
 from bcbio.broad.metrics import PicardMetricsParser
 
@@ -33,32 +35,67 @@ def _set_quality_flag(options, config):
     return options
 
 
-def _set_gtf(options, config):
+def _get_transcriptome_index(ref_file):
+    base_dir = os.path.dirname(os.path.dirname(ref_file))
+    base = os.path.basename(ref_file)
+    transcriptome_index = os.path.join(base_dir, "tophat", base + "_transcriptome")
+    if file_exists(transcriptome_index + ".1.bt2"):
+        return transcriptome_index
+    else:
+        return None
+
+def _get_gtf(ref_file, config):
     gtf_file = config.get("gtf", None)
-    if gtf_file is not None:
+    if not gtf_file:
+        base_dir = os.path.dirname(os.path.dirname(ref_file))
+        gtf_file = os.path.join(base_dir, "rnaseq/ref-transcripts.gtf")
+        if not file_exists(gtf_file):
+            gtf_file = None
+    return gtf_file
+
+def _set_transcriptome_option(options, config, ref_file):
+    # prefer transcriptome-index vs a GTF file if available
+    transcriptome_index = _get_transcriptome_index(ref_file)
+    if transcriptome_index:
+        options["transcriptome-index"] = transcriptome_index
+
+    gtf_file = _get_gtf(ref_file, config)
+    if gtf_file:
         options["GTF"] = gtf_file
     return options
 
-
 def _set_cores(options, config):
-    num_cores = config["algorithm"].get("num_cores", 1)
+    num_cores = config["algorithm"].get("num_cores", 0)
     if num_cores > 1 and "num-threads" not in options:
         options["num-threads"] = num_cores
     return options
 
+def _set_rg_options(options, names):
+    if not names:
+        return options
+    options["rg-id"] = names["rg"]
+    options["rg-sample"] = names["sample"]
+    options["rg-library"] = names["pl"]
+    options["rg-platform-unit"] = names["pu"]
+    return options
 
 def tophat_align(fastq_file, pair_file, ref_file, out_base, align_dir, config,
-                 rg_name=None):
+                 names=None):
     """
     run alignment using Tophat v2
     """
     options = get_in(config, ("resources", "tophat", "options"), {})
     options = _set_quality_flag(options, config)
-    options = _set_gtf(options, config)
+    options = _set_transcriptome_option(options, config, ref_file)
     options = _set_cores(options, config)
+    options = _set_rg_options(options, names)
 
     # select the correct bowtie option to use; tophat2 is ignoring this option
-    if _tophat_major_version(config) == 2 and _ref_version(ref_file) == 1:
+    if _tophat_major_version(config) == 1:
+        raise NotImplementedError("Tophat versions < 2.0 are not supported, please "
+                                  "download the newest version of Tophat here: "
+                                  "http://tophat.cbcb.umd.edu")
+    if _ref_version(ref_file) == 1:
         options["bowtie1"] = True
 
     out_dir = os.path.join(align_dir, "%s_tophat" % out_base)
@@ -86,13 +123,14 @@ def tophat_align(fastq_file, pair_file, ref_file, out_base, align_dir, config,
             # tophat requires options before arguments,
             # otherwise it silently ignores them
             tophat_ready = tophat_runner.bake(**ready_options)
-            tophat_ready(*files)
-    out_file_final = os.path.join(out_dir, "%s.sam" % out_base)
-    os.symlink(os.path.basename(out_file), out_file_final)
-    return out_file_final
+            cmd = str(tophat_ready.bake(*files))
+            do.run(cmd, "Running Tophat on %s and %s." % (fastq_file, pair_file), None)
+    out_sam_final = os.path.join(out_dir, "%s.sam" % out_base)
+    os.symlink(os.path.basename(out_file), out_sam_final)
+    return out_sam_final
 
 def align(fastq_file, pair_file, ref_file, out_base, align_dir, config,
-          rg_name=None):
+          names=None):
 
     out_dir = os.path.join(align_dir, "%s_tophat" % out_base)
     out_file = os.path.join(out_dir, _out_fnames[0])
@@ -110,7 +148,7 @@ def align(fastq_file, pair_file, ref_file, out_base, align_dir, config,
         exit(1)
 
     out_files = tophat_align(fastq_file, pair_file, ref_file, out_base,
-                             align_dir, config, rg_name=None)
+                             align_dir, config, names=None)
 
     return out_files
 
@@ -120,9 +158,11 @@ def _estimate_paired_innerdist(fastq_file, pair_file, ref_file, out_base,
     """Use Bowtie to estimate the inner distance of paired reads.
     """
     # skip initial reads for large file, but not for smaller
-    mean, stdev = _bowtie_for_innerdist("1000000", fastq_file, pair_file, ref_file,
-                                  out_base, out_dir, config)
+    # mean, stdev = _bowtie_for_innerdist("1000000", fastq_file, pair_file, ref_file,
+    #                              out_base, out_dir, config)
     # if it is a small file, use the old method
+    mean, stdev = _small_file_innerdist("100000", fastq_file, pair_file, ref_file,
+                                        out_base, out_dir, config, True)
     if not mean or not stdev:
         mean, stdev = _small_file_innerdist("1", fastq_file, pair_file, ref_file,
                                             out_base, out_dir, config, True)
@@ -171,8 +211,11 @@ def _small_file_innerdist(start, fastq_file, pair_file, ref_file, out_base,
         for read in work_sam:
             if read.is_proper_pair and read.is_read1:
                 dists.append(abs(read.isize) - 2 * read.rlen)
-    dist_stats = Stats(dists)
-    return int(round(dist_stats.mean())), int(round(dist_stats.standard_deviation()))
+    if dists:
+        dist_stats = Stats(dists)
+        return int(round(dist_stats.mean())), int(round(dist_stats.standard_deviation()))
+    else:
+        return None, None
 
 def _calculate_average_read_length(sam_file):
     with closing(pysam.Samfile(sam_file)) as work_sam:
