@@ -31,7 +31,7 @@ def split_by_barcode(fastq1, fastq2, multiplex, base_name, dirs, config):
         with file_transaction(bc_dir) as tx_bc_dir:
             with utils.chdir(tx_bc_dir):
                 tag_file, need_trim = _make_tag_file(multiplex, unmatched_str, config)
-                cl = [config["program"]["barcode"], tag_file,
+                cl = ["barcode_sort_trim.py", tag_file,
                       "%s_--b--_--r--_fastq.txt" % base_name,
                       fastq1]
                 if fastq2:
@@ -133,7 +133,8 @@ def add_multiplex_across_lanes(run_items, fastq_dir, fc_name):
     control, when run on a multiplexed flow cell. This checks for this
     situation and adds details to trim off the extra bases.
     """
-    fastq_dir = utils.add_full_path(fastq_dir)
+    if fastq_dir:
+        fastq_dir = utils.add_full_path(fastq_dir)
     # determine if we have multiplexes and collect expected size
     fastq_sizes = []
     tag_sizes = []
