@@ -22,6 +22,7 @@ SNPEFF_GENOME_REMAP = {
         "b37": SnpEffGenome("GRCh37.", "68", True),
         "hg19" : SnpEffGenome("hg19", "", True),
         "mm9" : SnpEffGenome("NCBIM37.", "68", False),
+        "mm10" : SnpEffGenome("GRCm38.", "71", False),
         "araTha_tair9": SnpEffGenome("athalianaTair9", "", False),
         "araTha_tair10": SnpEffGenome("athalianaTair10", "", False),
         }
@@ -40,7 +41,8 @@ def _installed_snpeff_genome(config_file, base_name):
     """Find the most recent installed genome for snpEff with the given name.
     """
     data_dir = _find_snpeff_datadir(config_file)
-    dbs = sorted(glob.glob(os.path.join(data_dir, "%s*" % base_name)), reverse=True)
+    dbs = [d for d in sorted(glob.glob(os.path.join(data_dir, "%s*" % base_name)), reverse=True)
+           if os.path.isdir(d)]
     if len(dbs) == 0:
         raise ValueError("No database found in %s for %s" % (data_dir, base_name))
     else:
@@ -63,23 +65,42 @@ def _get_snpeff_genome(gname, config):
     else:
         return "%s%s" % (ginfo.base, ginfo.default_version)
 
-def snpeff_effects(vcf_in, genome, config):
+def snpeff_effects(data):
     """Annotate input VCF file with effects calculated by snpEff.
     """
-    interval_file = config["algorithm"].get("hybrid_target", None)
-    if _vcf_has_items(vcf_in):
+    vcf_in = data["vrn_file"]
+    interval_file = data["config"]["algorithm"].get("hybrid_target", None)
+    if vcf_has_items(vcf_in):
         se_interval = (_convert_to_snpeff_interval(interval_file, vcf_in)
                        if interval_file else None)
         try:
-            vcf_file = _run_snpeff(vcf_in, _get_snpeff_genome(genome, config),
-                                   se_interval, "vcf", config)
+            vcf_file = _run_snpeff(vcf_in, _get_snpeff_genome(data["genome_build"], data["config"]),
+                                   se_interval, "vcf", data)
         finally:
             for fname in [se_interval]:
                 if fname and os.path.exists(fname):
                     os.remove(fname)
         return vcf_file
 
-def _run_snpeff(snp_in, genome, se_interval, out_format, config):
+def _snpeff_args_from_config(data):
+    """Retrieve snpEff arguments supplied through input configuration.
+    """
+    config = data["config"]
+    args = []
+    # General supplied arguments
+    resources = config_utils.get_resources("snpEff", config)
+    if resources.get("options"):
+        args += [str(x) for x in resources.get("options", [])]
+    # cancer specific calling arguments
+    if data.get("metadata", {}).get("phenotype") in ["tumor", "normal"]:
+        args += ["-cancer"]
+    # Provide options tuned to reporting variants in clinical environments
+    if config["algorithm"].get("clinical_reporting"):
+        args += ["-canon", "-hgvs"]
+    return args
+
+def _run_snpeff(snp_in, genome, se_interval, out_format, data):
+    config = data["config"]
     snpeff_jar = config_utils.get_jar("snpEff",
                                       config_utils.get_program("snpEff", config, "dir"))
     config_file = "%s.config" % os.path.splitext(snpeff_jar)[0]
@@ -90,16 +111,16 @@ def _run_snpeff(snp_in, genome, se_interval, out_format, config):
         cl = ["java"]
         cl += resources.get("jvm_opts", ["-Xms750m", "-Xmx5g"])
         cl += ["-jar", snpeff_jar, "eff", "-c", config_file,
-               "-1", "-i", "vcf", "-o", out_format, genome, snp_in]
+               "-noLog", "-1", "-i", "vcf", "-o", out_format, genome, snp_in]
         if se_interval:
             cl.extend(["-filterInterval", se_interval])
-        print " ".join(cl)
+        cl += _snpeff_args_from_config(data)
         with file_transaction(out_file) as tx_out_file:
             with open(tx_out_file, "w") as out_handle:
                 subprocess.check_call(cl, stdout=out_handle)
     return out_file
 
-def _vcf_has_items(in_file):
+def vcf_has_items(in_file):
     if os.path.exists(in_file):
         with open(in_file) as in_handle:
             for line in in_handle:
