@@ -11,7 +11,7 @@ from bcbio import utils
 from bcbio.distributed.transaction import file_transaction
 from bcbio.pipeline import config_utils
 from bcbio.provenance import do
-from bcbio.variation import effects, genotype
+from bcbio.variation import effects, vcfutils
 
 def prep_gemini_db(fnames, call_id, samples, data):
     """Prepare a gemini database from VCF inputs prepared with snpEff.
@@ -22,7 +22,7 @@ def prep_gemini_db(fnames, call_id, samples, data):
     is_population = len(fnames) > 1
     if is_population:
         gemini_vcf = "%s.vcf" % os.path.splitext(gemini_db)[0]
-        gemini_vcf = genotype.combine_variant_files(fnames, gemini_vcf, data["sam_ref"],
+        gemini_vcf = vcfutils.combine_variant_files(fnames, gemini_vcf, data["sam_ref"],
                                                     data["config"])
     else:
         gemini_vcf = fnames[0]
@@ -41,11 +41,16 @@ def _do_db_build(samples):
     """Confirm we should build a gemini database: need gemini + human samples.
     """
     config = samples[0]["config"]
-    gemini = config_utils.get_program("gemini", config)
+    try:
+        gemini = config_utils.get_program("gemini", config)
+    except config_utils.CmdNotFound:
+        return False
     try:
         p = subprocess.Popen([gemini, "-h"], stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
         p.wait()
         p.stdout.close()
+        if p.returncode not in [0, 1]:
+            return False
     except OSError:
         return False
     genomes = set()
@@ -65,7 +70,7 @@ def _group_by_batches(samples):
     out_retrieve = []
     extras = []
     for data in [x[0] for x in samples]:
-        if data["work_bam"]:
+        if data["work_bam"] and data.get("vrn_file") and effects.vcf_has_items(data["vrn_file"]):
             batch = data.get("metadata", {}).get("batch")
             if batch:
                 out_retrieve.append((batch, data))
