@@ -28,12 +28,11 @@ Usage:
 """
 import os
 import sys
-import subprocess
 
 from bcbio import install, workflow
 from bcbio.pipeline.run_info import get_run_info
 from bcbio.distributed import manage as messaging
-from bcbio.pipeline.config_utils import load_config
+from bcbio.pipeline.config_utils import load_system_config
 from bcbio.pipeline.main import run_main, parse_cl_args
 
 def main(config_file, fc_dir=None, run_info_yaml=None, numcores=None,
@@ -41,7 +40,7 @@ def main(config_file, fc_dir=None, run_info_yaml=None, numcores=None,
          profile=None, workflow=None, inputs=None, resources="",
          timeout=15, retries=None):
     work_dir = os.getcwd()
-    config = load_config(config_file)
+    config, config_file = load_system_config(config_file)
     if config.get("log_dir", None) is None:
         config["log_dir"] = os.path.join(work_dir, "log")
     paralleltype, numcores = _get_cores_and_type(config, fc_dir, run_info_yaml,
@@ -114,8 +113,7 @@ def _needed_workers(run_info):
     return len(set(names))
 
 if __name__ == "__main__":
-    config_file, kwargs = parse_cl_args(sys.argv[1:])
-    kwargs["config_file"] = config_file
+    kwargs = parse_cl_args(sys.argv[1:])
     if kwargs["upgrade"]:
         install.upgrade_bcbio(kwargs["args"])
     else:
